@@ -225,7 +225,7 @@ class Item(object):
 
     # modify_metadata()
     #_____________________________________________________________________________________
-    def modify_metadata(self, metadata, target='metadata'):
+    def modify_metadata(self, metadata, target='metadata', append=False):
         """Modify the metadata of an existing item on Archive.org.
 
         Note: The Metadata Write API does not yet comply with the
@@ -252,24 +252,20 @@ class Item(object):
         """
         access_key, secret_key = config.get_s3_keys()
         src = self.metadata.get(target, {})
-        dest = dict((src.items() + metadata.items()))
+        dest = src.copy()
+        dest.update(metadata)
 
         # Prepare patch to remove metadata elements with the value: "REMOVE_TAG".
-        for k,v in metadata.items():
-            if v == 'REMOVE_TAG' or not v:
-                del dest[k]
+        for key, val in metadata.items():
+            if val == 'REMOVE_TAG' or not val:
+                del dest[key]
+            if append:
+                dest[key] = '{0} {1}'.format(src[key], val)
 
         json_patch = make_patch(src, dest).patch
-        # Reformat patch to be compliant with version 02 of the Json-Patch standard.
-        patch = []
-        for p in json_patch:
-            pd = {p['op']: p['path']}
-            if p['op'] != 'remove':
-                pd['value'] = p['value']
-            patch.append(dict((k,v) for k,v in pd.items() if v))
 
         data = {
-            '-patch': json.dumps(patch),
+            '-patch': json.dumps(json_patch),
             '-target': target,
             'access': access_key,
             'secret': secret_key,
@@ -371,6 +367,8 @@ class Item(object):
         else:
             if not self.session:
                 self.session = Session()
+            if verbose:
+                stdout.write(' uploading: {id}\n'.format(id=key))
             prepared_request = request.prepare()
             return self.session.send(prepared_request, stream=True)
 
@@ -450,7 +448,7 @@ class File(object):
     # __repr__()
     #_____________________________________________________________________________________
     def __repr__(self):
-        return ('File(identifier={item.identifier!r}, '
+        return ('File(identifier={identifier!r}, '
                 'filename={name!r}, '
                 'size={size!r}, '
                 'source={source!r}, '
